#[repr(i32)]pub enum VoteExtensionType {
Default = 0,
ThresholdRecover = 1,
ThresholdRecoverRaw = 2,
}Variants
Default = 0
Unsupported
ThresholdRecover = 1
Sign canonical form of vote extension and threshold-recover signatures.
Deterministic vote extension - each validator in a quorum must provide the same vote extension data.
ThresholdRecoverRaw = 2
Sign raw form of vote extension and threshold-recover signatures.
Deterministic vote extension - each validator in a quorum must provide the same vote extension data. Use with caution - it can have severe security consequences, like replay attacks.
THRESHOLD_RECOVER_RAW alows overriding sign request ID with sign_request_id field
of ExtendVoteExtension.sign_request_id. If sign_request_id is provided, SHA256(sign_request_id) will be used as
a sign request ID.
It also changes how threshold-recover signatures are generated. Instead of signing canonical form of
threshold-recover signatures, it signs SHA256 of raw form of the vote extension (ExtendVoteExtension.extension).
Implementations
Sourceimpl VoteExtensionType
impl VoteExtensionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.