pub struct CanonicalProposal {
pub type: i32,
pub height: i64,
pub round: i64,
pub pol_round: i64,
pub block_id: Option<CanonicalBlockId>,
pub timestamp: Option<Timestamp>,
pub chain_id: String,
}Fields
type: i32type alias for byte
height: i64canonicalization requires fixed size encoding here
round: i64canonicalization requires fixed size encoding here
pol_round: i64block_id: Option<CanonicalBlockId>timestamp: Option<Timestamp>chain_id: StringImplementations
Sourceimpl CanonicalProposal
impl CanonicalProposal
Sourcepub fn type(&self) -> SignedMsgType
pub fn type(&self) -> SignedMsgType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SignedMsgType)
pub fn set_type(&mut self, value: SignedMsgType)
Sets type to the provided enum value.