pub struct CanonicalVote {
pub type: i32,
pub height: i64,
pub round: i64,
pub block_id: Vec<u8>,
pub state_id: Vec<u8>,
pub chain_id: String,
}Fields
type: i32type alias for byte
height: i64canonicalization requires fixed size encoding here
round: i64canonicalization requires fixed size encoding here
block_id: Vec<u8>block_id is a checksum (sha256) of CanonicalBlockID for the block being voted on
state_id: Vec<u8>state_id is a checksum (sha256) of StateID message for the block being voted on
chain_id: Stringchain_id is last, to allow variable length of string
Implementations
Sourceimpl CanonicalVote
impl CanonicalVote
Sourcepub fn type(&self) -> SignedMsgType
pub fn type(&self) -> SignedMsgType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SignedMsgType)
pub fn set_type(&mut self, value: SignedMsgType)
Sets type to the provided enum value.