pub struct ConsensusParams {
pub block: Option<BlockParams>,
pub evidence: Option<EvidenceParams>,
pub validator: Option<ValidatorParams>,
pub version: Option<VersionParams>,
pub synchrony: Option<SynchronyParams>,
pub timeout: Option<TimeoutParams>,
pub abci: Option<AbciParams>,
}Expand description
ConsensusParams contains consensus critical parameters that determine the validity of blocks.
Fields
block: Option<BlockParams>evidence: Option<EvidenceParams>validator: Option<ValidatorParams>version: Option<VersionParams>DEPRECATED. This will be removed in a future release. Replaced by ResponsePrepareProposal.app_version
synchrony: Option<SynchronyParams>timeout: Option<TimeoutParams>abci: Option<AbciParams>Trait Implementations
Sourceimpl Clone for ConsensusParams
impl Clone for ConsensusParams
Sourcefn clone(&self) -> ConsensusParams
fn clone(&self) -> ConsensusParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsensusParams
impl Debug for ConsensusParams
Sourceimpl Default for ConsensusParams
impl Default for ConsensusParams
Sourceimpl<'de> Deserialize<'de> for ConsensusParams
impl<'de> Deserialize<'de> for ConsensusParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ConsensusParams
impl Hash for ConsensusParams
Sourceimpl Message for ConsensusParams
impl Message for ConsensusParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ConsensusParams
impl PartialEq for ConsensusParams
Sourceimpl Serialize for ConsensusParams
impl Serialize for ConsensusParams
impl Eq for ConsensusParams
impl StructuralPartialEq for ConsensusParams