pub struct Header {Show 17 fields
pub version: Option<Consensus>,
pub chain_id: String,
pub height: i64,
pub time: Option<Timestamp>,
pub last_block_id: Option<BlockId>,
pub last_commit_hash: Vec<u8>,
pub data_hash: Vec<u8>,
pub validators_hash: Vec<u8>,
pub next_validators_hash: Vec<u8>,
pub consensus_hash: Vec<u8>,
pub next_consensus_hash: Vec<u8>,
pub app_hash: Vec<u8>,
pub results_hash: Vec<u8>,
pub evidence_hash: Vec<u8>,
pub proposed_app_version: u64,
pub proposer_pro_tx_hash: Vec<u8>,
pub core_chain_locked_height: u32,
}Expand description
Header defines the structure of a Tendermint block header.
Fields
version: Option<Consensus>basic block info
chain_id: Stringheight: i64time: Option<Timestamp>Time of the block, truncated (rounded down) to millisecond
last_block_id: Option<BlockId>prev block info
last_commit_hash: Vec<u8>hashes of block data
commit from validators from the last block
data_hash: Vec<u8>transactions
validators_hash: Vec<u8>hashes from the app output from the prev block
validators for the current block
next_validators_hash: Vec<u8>validators for the next block
consensus_hash: Vec<u8>consensus params for current block
next_consensus_hash: Vec<u8>consensus params for next block
app_hash: Vec<u8>state after txs from the previous block
results_hash: Vec<u8>root hash of all results from the txs from current block
evidence_hash: Vec<u8>consensus info
evidence included in the block
proposed_app_version: u64proposer’s latest available app protocol version
proposer_pro_tx_hash: Vec<u8>original proposer of the block
core_chain_locked_height: u32core chain height used to verify this block