pub struct Proposal {
pub type: i32,
pub height: i64,
pub round: i32,
pub pol_round: i32,
pub block_id: Option<BlockId>,
pub timestamp: Option<Timestamp>,
pub signature: Vec<u8>,
pub core_chain_locked_height: u32,
pub core_chain_lock_update: Option<CoreChainLock>,
}Fields
type: i32height: i64round: i32pol_round: i32block_id: Option<BlockId>timestamp: Option<Timestamp>signature: Vec<u8>core_chain_locked_height: u32core chain locked height to be used to sign/verify current block
core_chain_lock_update: Option<CoreChainLock>core chain lock to be used to sign/verify next block
Implementations
Sourceimpl Proposal
impl Proposal
Sourcepub fn type(&self) -> SignedMsgType
pub fn type(&self) -> SignedMsgType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SignedMsgType)
pub fn set_type(&mut self, value: SignedMsgType)
Sets type to the provided enum value.