pub struct StateId {
pub app_version: u64,
pub height: u64,
pub app_hash: Vec<u8>,
pub core_chain_locked_height: u32,
pub time: u64,
}Expand description
StateID represents essential information required to verify state, document and transactions. It is meant to be used by light clients (like mobile apps) to verify proofs.
Fields
app_version: u64AppVersion used when generating the block, equals to Header.Version.App.
height: u64Height of block containing this state ID.
app_hash: Vec<u8>AppHash used in current block, equal to Header.AppHash. 32 bytes.
core_chain_locked_height: u32CoreChainLockedHeight for the block, equal to Header.CoreChainLockedHeight.
time: u64Time of the block in milliseconds since epoch, truncated (rounded down) to milliseconds