pub struct SynchronyParams {
pub message_delay: Option<Duration>,
pub precision: Option<Duration>,
}Expand description
SynchronyParams configure the bounds under which a proposed block’s timestamp is considered valid. These parameters are part of the proposer-based timestamps algorithm. For more information, see the specification of proposer-based timestamps: https://github.com/tendermint/tendermint/tree/master/spec/consensus/proposer-based-timestamp
Fields
message_delay: Option<Duration>message_delay bounds how long a proposal message may take to reach all validators on a network and still be considered valid.
precision: Option<Duration>precision bounds how skewed a proposer’s clock may be from any validator on the network while still producing valid proposals.