TimeoutParams

Struct TimeoutParams 

pub struct TimeoutParams {
    pub propose: Option<Duration>,
    pub propose_delta: Option<Duration>,
    pub vote: Option<Duration>,
    pub vote_delta: Option<Duration>,
}
TimeoutParams configure the timeouts for the steps of the Tendermint consensus algorithm.

Fields

propose: Option<Duration>

These fields configure the timeouts for the propose step of the Tendermint consensus algorithm: propose is the initial timeout and propose_delta determines how much the timeout grows in subsequent rounds. For the first round, this propose timeout is used and for every subsequent round, the timeout grows by propose_delta.

For example: With propose = 10ms, propose_delta = 5ms, the first round’s propose phase timeout would be 10ms, the second round’s would be 15ms, the third 20ms and so on.

If a node waiting for a proposal message does not receive one matching its current height and round before this timeout, the node will issue a nil prevote for the round and advance to the next step.

propose_delta: Option<Duration>vote: Option<Duration>

vote along with vote_delta configure the timeout for both of the prevote and precommit steps of the Tendermint consensus algorithm.

These parameters influence the vote step timeouts in the the same way that the propose and propose_delta parameters do to the proposal step.

The vote timeout does not begin until a quorum of votes has been received. Once a quorum of votes has been seen and this timeout elapses, Tendermint will procced to the next step of the consensus algorithm. If Tendermint receives all of the remaining votes before the end of the timeout, it will proceed to the next step immediately.

vote_delta: Option<Duration>