pub struct ValidatorParams {
pub pub_key_types: Vec<String>,
pub voting_power_threshold: Option<u64>,
}Expand description
ValidatorParams restrict the public key types validators can use. NOTE: uses ABCI pubkey naming, not Amino names.
Fields
pub_key_types: Vec<String>voting_power_threshold: Option<u64>Threshold defines the minimum voting power of validators that must vote for a proposal to be considered signed and added to the block.
For Dash Platform, the voting power can be calculated by multiply of the number of validators
and const DefaultDashVotingPower == 100.
The following validation rules MUST be enforced:
- For validator sets containing 1 or 2 validators, the threshold MUST be equal to the total voting power of these validators.
- For validator set with 3 validators, the threshold MUST be equal or greater than 2/3 of the total voting power.
- For validator sets containing more than 3 validators, the threshold MUST be greater than 2/3 of the total voting power.
If set to 0, default value is determined based on LLMQ quorum type defined for the network, with a fall back to 2/3 + 1 of the total voting power.
If absent, previous value is used.
[(gogoproto.nullable) = true]
Implementations
Sourceimpl ValidatorParams
impl ValidatorParams
Sourcepub fn voting_power_threshold(&self) -> u64
pub fn voting_power_threshold(&self) -> u64
Returns the value of voting_power_threshold, or the default value if voting_power_threshold is unset.