pub struct VersionParams {
pub app_version: u64,
pub consensus_version: i32,
}Expand description
VersionParams contains the ABCI application version.
Fields
app_version: u64consensus_version: i32Version of consensus protocol, used to upgrade consensus without hard forks
Implementations
Sourceimpl VersionParams
impl VersionParams
Sourcepub fn consensus_version(&self) -> ConsensusVersion
pub fn consensus_version(&self) -> ConsensusVersion
Returns the enum value of consensus_version, or the default if the field is set to an invalid enum value.
Sourcepub fn set_consensus_version(&mut self, value: ConsensusVersion)
pub fn set_consensus_version(&mut self, value: ConsensusVersion)
Sets consensus_version to the provided enum value.