Vote

Struct Vote 

pub struct Vote {
    pub type: i32,
    pub height: i64,
    pub round: i32,
    pub block_id: Option<BlockId>,
    pub validator_pro_tx_hash: Vec<u8>,
    pub validator_index: i32,
    pub block_signature: Vec<u8>,
    pub vote_extensions: Vec<VoteExtension>,
}
Vote represents a prevote, precommit, or commit vote from validators for consensus.

Fields

type: i32height: i64round: i32block_id: Option<BlockId>

zero if vote is nil.

validator_pro_tx_hash: Vec<u8>validator_index: i32block_signature: Vec<u8>vote_extensions: Vec<VoteExtension>

Vote extension provided by the application. Only valid for precommit messages. Vote extension signature by the validator if they participated in consensus for the associated block. Only valid for precommit messages.

Implementations

Source

impl Vote

pub fn type(&self) -> SignedMsgType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: SignedMsgType)

Sets type to the provided enum value.