pub struct VoteExtension {
pub type: i32,
pub extension: Vec<u8>,
pub signature: Vec<u8>,
pub sign_request_id: Option<Vec<u8>>,
}Fields
type: i32extension: Vec<u8>signature: Vec<u8>Sign request ID that will be used to sign the vote extensions.
Tenderdash will use checksum of sign_request_id when generating quorum signatures of
THRESHOLD_RECOVER vote extensions.
sign_request_id: Option<Vec<u8>>If not set, Tenderdash will generate it based on height and round.
If set, it SHOULD be unique per voting round, and it MUST start with dpevote or \x06plwdtx string.
Use with caution - it can have severe security consequences.
Implementations
Sourceimpl VoteExtension
impl VoteExtension
Sourcepub fn type(&self) -> VoteExtensionType
pub fn type(&self) -> VoteExtensionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: VoteExtensionType)
pub fn set_type(&mut self, value: VoteExtensionType)
Sets type to the provided enum value.
Sourcepub fn sign_request_id(&self) -> &[u8] ⓘ
pub fn sign_request_id(&self) -> &[u8] ⓘ
Returns the value of sign_request_id, or the default value if sign_request_id is unset.